@@ -26,6 +26,7 @@
 #include <stdio.h>
 
 #include "cpufreq-monitor-cpuinfo.h"
+#include "cpufreq-utils.h"
 
 static void     cpufreq_monitor_cpuinfo_class_init (CPUFreqMonitorCPUInfoClass *klass);
 
@@ -69,8 +70,8 @@ cpufreq_monitor_cpuinfo_run (CPUFreqMonitor *monitor)
         GError *error = NULL;
 
         file = g_strdup ("/proc/cpuinfo");
-        if (!g_file_get_contents (file, &buffer, NULL, &error)) {
-                g_warning (error->message);
+        if (!cpufreq_file_get_contents (file, &buffer, NULL, &error)) {
+                g_warning ("%s", error->message);
                 g_error_free (error);
 
                 g_free (file);
