@@ -11,7 +11,6 @@
  *
  */
 
-#include <gnome.h>
 #include <panel-applet.h>
 
 #include <libgweather/gweather-gconf.h>
@@ -49,9 +48,6 @@ struct _GWeatherApplet
 
 	/* dialog stuff */
 	GtkWidget *details_dialog;
-
-	GdkPixbuf *applet_pixbuf;
-	GdkBitmap *applet_mask;
 };
 
 G_END_DECLS
