@@ -198,7 +198,7 @@ modem_applet_init (ModemApplet *applet)
 
   pixbuf = gtk_icon_theme_load_icon (priv->icon_theme, "gnome-modem-monitor-applet", 48, 0, NULL);
   gtk_image_set_from_pixbuf (GTK_IMAGE (priv->report_window_image), pixbuf);
-  gdk_pixbuf_unref (pixbuf);
+  g_object_unref (pixbuf);
 
   priv->configured = FALSE;
   priv->enabled = FALSE;
@@ -210,7 +210,7 @@ modem_applet_init (ModemApplet *applet)
   priv->directives = NULL;
   priv->directives_id = g_timeout_add (250, (GSourceFunc) dispatch_directives, applet);
   priv->directive_running = FALSE;
-  priv->tooltip_id = g_timeout_add (1000, (GSourceFunc) update_tooltip, applet);
+  priv->tooltip_id = g_timeout_add_seconds (1, (GSourceFunc) update_tooltip, applet);
 
   launch_backend (applet, FALSE);
   gtk_container_add (GTK_CONTAINER (applet), priv->image);
@@ -266,7 +266,7 @@ modem_applet_change_background (PanelApplet *app,
   gtk_widget_set_style (GTK_WIDGET (applet), NULL);
   rc_style = gtk_rc_style_new ();
   gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
-  gtk_rc_style_unref (rc_style);
+  g_object_unref (rc_style);
 
   switch (type)
     {
@@ -460,7 +460,7 @@ read_xml (ModemApplet *applet, gboolean show_report)
   /* if show_report, create pulse timeout and show window */
   if (show_report)
     {
-      priv->progress_id = gtk_timeout_add (200, (GSourceFunc) pulse_progressbar, priv->report_window_progress);
+      priv->progress_id = g_timeout_add (200, (GSourceFunc) pulse_progressbar, priv->report_window_progress);
       gtk_window_set_screen (GTK_WINDOW (priv->report_window), gtk_widget_get_screen (GTK_WIDGET (applet)));
       gtk_widget_show (priv->report_window);
     }
@@ -878,8 +878,8 @@ launch_backend (ModemApplet *applet, gboolean root_auth)
 	  close (p[1]);
 
 	  priv->read_fd = p[0];
-	  priv->timeout_id = g_timeout_add (1000, (GSourceFunc) check_backend, applet);
-	  priv->info_id = g_timeout_add (2500, (GSourceFunc) update_info, applet);
+	  priv->timeout_id = g_timeout_add_seconds (1, (GSourceFunc) check_backend, applet);
+	  priv->info_id = g_timeout_add_seconds (3, (GSourceFunc) update_info, applet);
 	  priv->read_stream = fdopen (priv->read_fd, "r");
 	  priv->write_stream = fdopen (priv->write_fd, "w");
 	  priv->has_root = root_auth;
